function [residual, g1, g2, g3] = Model_main_closed_nirp_dynamic(y, x, params, steady_state, it_)
%
% Status : Computes dynamic model for Dynare
%
% Inputs :
%   y         [#dynamic variables by 1] double    vector of endogenous variables in the order stored
%                                                 in M_.lead_lag_incidence; see the Manual
%   x         [nperiods by M_.exo_nbr] double     matrix of exogenous variables (in declaration order)
%                                                 for all simulation periods
%   steady_state  [M_.endo_nbr by 1] double       vector of steady state values
%   params    [M_.param_nbr by 1] double          vector of parameter values in declaration order
%   it_       scalar double                       time period for exogenous variables for which to evaluate the model
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the dynamic model equations in order of 
%                                          declaration of the equations.
%                                          Dynare may prepend auxiliary equations, see M_.aux_vars
%   g1        [M_.endo_nbr by #dynamic variables] double    Jacobian matrix of the dynamic model equations;
%                                                           rows: equations in order of declaration
%                                                           columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%   g2        [M_.endo_nbr by (#dynamic variables)^2] double   Hessian matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%   g3        [M_.endo_nbr by (#dynamic variables)^3] double   Third order derivative matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

%
% Model equations
%

residual = zeros(31, 1);
T20 = y(48)^(-1);
T25 = y(15)^(-params(16));
T108 = y(48)^(params(5)-1);
T117 = y(48)^params(5);
T140 = params(1)*y(19)^params(5);
T206 = params(6)*y(19)^(-1);
lhs =y(17);
rhs =params(2)*(y(15)/y(1))^(-params(16));
residual(1)= lhs-rhs;
lhs =1;
rhs =y(46)*T20*y(20);
residual(2)= lhs-rhs;
lhs =T25*y(24);
rhs =params(9)*y(25)^params(4);
residual(3)= lhs-rhs;
lhs =y(18);
rhs =params(3)*(y(16)/y(2))^(-params(16));
residual(4)= lhs-rhs;
lhs =1;
rhs =T20*y(47)*y(49);
residual(5)= lhs-rhs;
lhs =y(21);
rhs =(1+params(8)*y(26))/y(6);
residual(6)= lhs-rhs;
lhs =y(16);
rhs =y(26)*y(40);
residual(7)= lhs-rhs;
lhs =y(27);
rhs =1-params(6)+params(6)*y(29)*y(28);
residual(8)= lhs-rhs;
lhs =y(28);
rhs =y(20)*T20*y(46)*(1+y(30))/y(29)*y(50)-y(31)*y(32)/(y(29)*y(34));
residual(9)= lhs-rhs;
lhs =T20*y(46)*y(50)*(y(49)-y(20));
rhs =y(29)*y(30)/(1+y(30));
residual(10)= lhs-rhs;
lhs =T20*y(46)*y(50)*(y(22)-y(20));
rhs =(-y(31))/(1+y(30));
residual(11)= lhs-rhs;
lhs =y(35);
rhs =params(5)/(params(5)-1)*y(36)/y(37);
residual(12)= lhs-rhs;
lhs =y(37);
rhs =y(39)+y(46)*params(1)*T108*y(52);
residual(13)= lhs-rhs;
lhs =y(36);
rhs =y(39)*y(24)/y(38)+y(46)*params(1)*T117*y(51);
residual(14)= lhs-rhs;
lhs =y(39);
rhs =y(25)*y(38)/y(43);
residual(15)= lhs-rhs;
lhs =1;
rhs =(1-params(1))*y(35)^(1-params(5))+params(1)*y(19)^(params(5)-1);
residual(16)= lhs-rhs;
lhs =y(43);
rhs =(1-params(1))*y(35)^(-params(5))+T140*y(14);
residual(17)= lhs-rhs;
lhs =y(26)*y(41);
rhs =y(32);
residual(18)= lhs-rhs;
lhs =log(y(23));
rhs =(1-params(13))*log(params(21))+params(13)*log(y(5))+(1-params(13))*(params(11)*(log(y(19))-log(params(7)))+params(12)*(log(y(39))-log(y(11))))+params(18)*x(it_, 1);
residual(19)= lhs-rhs;
lhs =y(22);
rhs =y(23);
residual(20)= lhs-rhs;
lhs =y(20);
rhs =1;
residual(21)= lhs-rhs;
lhs =log(y(41));
rhs =(1-params(13))*log(params(23))+params(13)*log(y(12))+(params(11)*(log(y(19))-log(params(7)))+params(12)*(log(y(39))-log(y(11))))*(1-params(13))*params(10)+params(18)*x(it_, 4);
residual(22)= lhs-rhs;
lhs =y(32)+y(26)*y(42);
rhs =y(34)+y(33);
residual(23)= lhs-rhs;
lhs =y(26)*y(42);
rhs =y(28)*y(34);
residual(24)= lhs-rhs;
lhs =y(34);
rhs =T206*(y(6)*(y(21)-y(3))*y(13)+(y(4)-y(3))*y(8)+y(3)*y(9))+params(20);
residual(25)= lhs-rhs;
lhs =y(40);
rhs =y(41)+y(42);
residual(26)= lhs-rhs;
lhs =y(39);
rhs =y(15)+y(16);
residual(27)= lhs-rhs;
lhs =log(y(38));
rhs =params(14)*log(y(10))+params(17)*x(it_, 2);
residual(28)= lhs-rhs;
lhs =log(y(29));
rhs =(1-params(15))*log(params(22))+params(15)*log(y(7))+params(19)*x(it_, 3);
residual(29)= lhs-rhs;
lhs =y(44);
rhs =y(15)+y(16);
residual(30)= lhs-rhs;
lhs =y(45);
rhs =y(21)/y(20);
residual(31)= lhs-rhs;
if nargout >= 2,
  g1 = zeros(31, 56);

  %
  % Jacobian matrix
  %

T261 = getPowerDeriv(y(15)/y(1),(-params(16)),1);
T274 = getPowerDeriv(y(16)/y(2),(-params(16)),1);
T316 = getPowerDeriv(y(48),(-1),1);
  g1(1,1)=(-(params(2)*(-y(15))/(y(1)*y(1))*T261));
  g1(1,15)=(-(params(2)*T261*1/y(1)));
  g1(1,17)=1;
  g1(2,46)=(-(T20*y(20)));
  g1(2,48)=(-(y(20)*y(46)*T316));
  g1(2,20)=(-(y(46)*T20));
  g1(3,15)=y(24)*getPowerDeriv(y(15),(-params(16)),1);
  g1(3,24)=T25;
  g1(3,25)=(-(params(9)*getPowerDeriv(y(25),params(4),1)));
  g1(4,2)=(-(params(3)*(-y(16))/(y(2)*y(2))*T274));
  g1(4,16)=(-(params(3)*T274*1/y(2)));
  g1(4,18)=1;
  g1(5,47)=(-(T20*y(49)));
  g1(5,48)=(-(y(49)*y(47)*T316));
  g1(5,49)=(-(T20*y(47)));
  g1(6,21)=1;
  g1(6,6)=(-((-(1+params(8)*y(26)))/(y(6)*y(6))));
  g1(6,26)=(-(params(8)/y(6)));
  g1(7,16)=1;
  g1(7,26)=(-y(40));
  g1(7,40)=(-y(26));
  g1(8,27)=1;
  g1(8,28)=(-(params(6)*y(29)));
  g1(8,29)=(-(params(6)*y(28)));
  g1(9,46)=(-(y(20)*T20*(1+y(30))/y(29)*y(50)));
  g1(9,48)=(-(y(20)*y(46)*(1+y(30))/y(29)*y(50)*T316));
  g1(9,20)=(-(T20*y(46)*(1+y(30))/y(29)*y(50)));
  g1(9,50)=(-(y(20)*T20*y(46)*(1+y(30))/y(29)));
  g1(9,28)=1;
  g1(9,29)=(-(y(20)*T20*y(50)*y(46)*(-(1+y(30)))/(y(29)*y(29))-(-(y(31)*y(32)*y(34)))/(y(29)*y(34)*y(29)*y(34))));
  g1(9,30)=(-(y(20)*T20*y(50)*y(46)*1/y(29)));
  g1(9,31)=y(32)/(y(29)*y(34));
  g1(9,32)=y(31)/(y(29)*y(34));
  g1(9,34)=(-(y(29)*y(31)*y(32)))/(y(29)*y(34)*y(29)*y(34));
  g1(10,46)=(y(49)-y(20))*T20*y(50);
  g1(10,48)=(y(49)-y(20))*y(46)*y(50)*T316;
  g1(10,20)=(-(T20*y(46)*y(50)));
  g1(10,49)=T20*y(46)*y(50);
  g1(10,50)=y(46)*T20*(y(49)-y(20));
  g1(10,29)=(-(y(30)/(1+y(30))));
  g1(10,30)=(-((y(29)*(1+y(30))-y(29)*y(30))/((1+y(30))*(1+y(30)))));
  g1(11,46)=(y(22)-y(20))*T20*y(50);
  g1(11,48)=(y(22)-y(20))*y(46)*y(50)*T316;
  g1(11,20)=(-(T20*y(46)*y(50)));
  g1(11,22)=T20*y(46)*y(50);
  g1(11,50)=y(46)*T20*(y(22)-y(20));
  g1(11,30)=(-(y(31)/((1+y(30))*(1+y(30)))));
  g1(11,31)=(-((-1)/(1+y(30))));
  g1(12,35)=1;
  g1(12,36)=(-(params(5)/(params(5)-1)/y(37)));
  g1(12,37)=(-((-(params(5)/(params(5)-1)*y(36)))/(y(37)*y(37))));
  g1(13,46)=(-(y(52)*params(1)*T108));
  g1(13,48)=(-(y(52)*y(46)*params(1)*getPowerDeriv(y(48),params(5)-1,1)));
  g1(13,37)=1;
  g1(13,52)=(-(y(46)*params(1)*T108));
  g1(13,39)=(-1);
  g1(14,46)=(-(y(51)*params(1)*T117));
  g1(14,48)=(-(y(51)*y(46)*params(1)*getPowerDeriv(y(48),params(5),1)));
  g1(14,24)=(-(y(39)*1/y(38)));
  g1(14,36)=1;
  g1(14,51)=(-(y(46)*params(1)*T117));
  g1(14,38)=(-(y(39)*(-y(24))/(y(38)*y(38))));
  g1(14,39)=(-(y(24)/y(38)));
  g1(15,25)=(-(y(38)/y(43)));
  g1(15,38)=(-(y(25)/y(43)));
  g1(15,39)=1;
  g1(15,43)=(-((-(y(25)*y(38)))/(y(43)*y(43))));
  g1(16,19)=(-(params(1)*getPowerDeriv(y(19),params(5)-1,1)));
  g1(16,35)=(-((1-params(1))*getPowerDeriv(y(35),1-params(5),1)));
  g1(17,19)=(-(y(14)*params(1)*getPowerDeriv(y(19),params(5),1)));
  g1(17,35)=(-((1-params(1))*getPowerDeriv(y(35),(-params(5)),1)));
  g1(17,14)=(-T140);
  g1(17,43)=1;
  g1(18,26)=y(41);
  g1(18,32)=(-1);
  g1(18,41)=y(26);
  g1(19,19)=(-((1-params(13))*params(11)*1/y(19)));
  g1(19,5)=(-(params(13)*1/y(5)));
  g1(19,23)=1/y(23);
  g1(19,11)=(-((1-params(13))*params(12)*(-(1/y(11)))));
  g1(19,39)=(-((1-params(13))*params(12)*1/y(39)));
  g1(19,53)=(-params(18));
  g1(20,22)=1;
  g1(20,23)=(-1);
  g1(21,20)=1;
  g1(22,19)=(-((1-params(13))*params(10)*params(11)*1/y(19)));
  g1(22,11)=(-((1-params(13))*params(10)*params(12)*(-(1/y(11)))));
  g1(22,39)=(-((1-params(13))*params(10)*params(12)*1/y(39)));
  g1(22,12)=(-(params(13)*1/y(12)));
  g1(22,41)=1/y(41);
  g1(22,56)=(-params(18));
  g1(23,26)=y(42);
  g1(23,32)=1;
  g1(23,33)=(-1);
  g1(23,34)=(-1);
  g1(23,42)=y(26);
  g1(24,26)=y(42);
  g1(24,28)=(-y(34));
  g1(24,34)=(-y(28));
  g1(24,42)=y(26);
  g1(25,19)=(-((y(6)*(y(21)-y(3))*y(13)+(y(4)-y(3))*y(8)+y(3)*y(9))*params(6)*getPowerDeriv(y(19),(-1),1)));
  g1(25,3)=(-(T206*(y(9)+y(13)*(-y(6))-y(8))));
  g1(25,21)=(-(T206*y(6)*y(13)));
  g1(25,4)=(-(T206*y(8)));
  g1(25,6)=(-(T206*(y(21)-y(3))*y(13)));
  g1(25,8)=(-(T206*(y(4)-y(3))));
  g1(25,9)=(-(T206*y(3)));
  g1(25,34)=1;
  g1(25,13)=(-(T206*y(6)*(y(21)-y(3))));
  g1(26,40)=1;
  g1(26,41)=(-1);
  g1(26,42)=(-1);
  g1(27,15)=(-1);
  g1(27,16)=(-1);
  g1(27,39)=1;
  g1(28,10)=(-(params(14)*1/y(10)));
  g1(28,38)=1/y(38);
  g1(28,54)=(-params(17));
  g1(29,7)=(-(params(15)*1/y(7)));
  g1(29,29)=1/y(29);
  g1(29,55)=(-params(19));
  g1(30,15)=(-1);
  g1(30,16)=(-1);
  g1(30,44)=1;
  g1(31,20)=(-((-y(21))/(y(20)*y(20))));
  g1(31,21)=(-(1/y(20)));
  g1(31,45)=1;

if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],31,3136);
if nargout >= 4,
  %
  % Third order derivatives
  %

  g3 = sparse([],[],[],31,175616);
end
end
end
end
