function [residual, g1, g2, g3] = Model_main_closed_nirp_static(y, x, params)
%
% Status : Computes static model for Dynare
%
% Inputs : 
%   y         [M_.endo_nbr by 1] double    vector of endogenous variables in declaration order
%   x         [M_.exo_nbr by 1] double     vector of exogenous variables in declaration order
%   params    [M_.param_nbr by 1] double   vector of parameter values in declaration order
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the static model equations 
%                                          in order of declaration of the equations.
%                                          Dynare may prepend or append auxiliary equations, see M_.aux_vars
%   g1        [M_.endo_nbr by M_.endo_nbr] double    Jacobian matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%   g2        [M_.endo_nbr by (M_.endo_nbr)^2] double   Hessian matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%   g3        [M_.endo_nbr by (M_.endo_nbr)^3] double   Third derivatives matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

residual = zeros( 31, 1);

%
% Model equations
%

T15 = y(5)^(-1);
T20 = y(1)^(-params(16));
T95 = y(5)^(params(5)-1);
T103 = y(5)^params(5);
lhs =y(3);
rhs =params(2);
residual(1)= lhs-rhs;
lhs =1;
rhs =y(3)*T15*y(6);
residual(2)= lhs-rhs;
lhs =T20*y(10);
rhs =params(9)*y(11)^params(4);
residual(3)= lhs-rhs;
lhs =y(4);
rhs =params(3);
residual(4)= lhs-rhs;
lhs =1;
rhs =T15*y(4)*y(7);
residual(5)= lhs-rhs;
lhs =y(7);
rhs =(1+params(8)*y(12))/y(12);
residual(6)= lhs-rhs;
lhs =y(2);
rhs =y(12)*y(26);
residual(7)= lhs-rhs;
lhs =y(13);
rhs =1-params(6)+params(6)*y(15)*y(14);
residual(8)= lhs-rhs;
lhs =y(14);
rhs =y(6)*T15*y(13)*y(3)*(1+y(16))/y(15)-y(17)*y(18)/(y(15)*y(20));
residual(9)= lhs-rhs;
lhs =T15*y(3)*y(13)*(y(7)-y(6));
rhs =y(15)*y(16)/(1+y(16));
residual(10)= lhs-rhs;
lhs =T15*y(3)*y(13)*(y(8)-y(6));
rhs =(-y(17))/(1+y(16));
residual(11)= lhs-rhs;
lhs =y(21);
rhs =params(5)/(params(5)-1)*y(22)/y(23);
residual(12)= lhs-rhs;
lhs =y(23);
rhs =y(25)+y(23)*y(3)*params(1)*T95;
residual(13)= lhs-rhs;
lhs =y(22);
rhs =y(25)*y(10)/y(24)+y(22)*y(3)*params(1)*T103;
residual(14)= lhs-rhs;
lhs =y(25);
rhs =y(11)*y(24)/y(29);
residual(15)= lhs-rhs;
lhs =1;
rhs =(1-params(1))*y(21)^(1-params(5))+params(1)*T95;
residual(16)= lhs-rhs;
lhs =y(29);
rhs =(1-params(1))*y(21)^(-params(5))+y(29)*params(1)*T103;
residual(17)= lhs-rhs;
lhs =y(12)*y(27);
rhs =y(18);
residual(18)= lhs-rhs;
lhs =log(y(9));
rhs =(1-params(13))*log(params(21))+log(y(9))*params(13)+(1-params(13))*params(11)*(log(y(5))-log(params(7)))+params(18)*x(1);
residual(19)= lhs-rhs;
lhs =y(8);
rhs =y(9);
residual(20)= lhs-rhs;
lhs =y(6);
rhs =1;
residual(21)= lhs-rhs;
lhs =log(y(27));
rhs =(1-params(13))*log(params(23))+params(13)*log(y(27))+params(11)*(log(y(5))-log(params(7)))*(1-params(13))*params(10)+params(18)*x(4);
residual(22)= lhs-rhs;
lhs =y(18)+y(12)*y(28);
rhs =y(20)+y(19);
residual(23)= lhs-rhs;
lhs =y(12)*y(28);
rhs =y(14)*y(20);
residual(24)= lhs-rhs;
lhs =y(20);
rhs =T15*params(6)*(y(28)*y(12)*(y(7)-y(6))+y(18)*(y(8)-y(6))+y(6)*y(20))+params(20);
residual(25)= lhs-rhs;
lhs =y(26);
rhs =y(27)+y(28);
residual(26)= lhs-rhs;
lhs =y(25);
rhs =y(1)+y(2);
residual(27)= lhs-rhs;
lhs =log(y(24));
rhs =log(y(24))*params(14)+params(17)*x(2);
residual(28)= lhs-rhs;
lhs =log(y(15));
rhs =(1-params(15))*log(params(22))+log(y(15))*params(15)+params(19)*x(3);
residual(29)= lhs-rhs;
lhs =y(30);
rhs =y(1)+y(2);
residual(30)= lhs-rhs;
lhs =y(31);
rhs =y(7)/y(6);
residual(31)= lhs-rhs;
if ~isreal(residual)
  residual = real(residual)+imag(residual).^2;
end
if nargout >= 2,
  g1 = zeros(31, 31);

  %
  % Jacobian matrix
  %

T235 = getPowerDeriv(y(5),(-1),1);
T248 = getPowerDeriv(y(5),params(5)-1,1);
T252 = getPowerDeriv(y(5),params(5),1);
  g1(1,3)=1;
  g1(2,3)=(-(T15*y(6)));
  g1(2,5)=(-(y(6)*y(3)*T235));
  g1(2,6)=(-(y(3)*T15));
  g1(3,1)=y(10)*getPowerDeriv(y(1),(-params(16)),1);
  g1(3,10)=T20;
  g1(3,11)=(-(params(9)*getPowerDeriv(y(11),params(4),1)));
  g1(4,4)=1;
  g1(5,4)=(-(T15*y(7)));
  g1(5,5)=(-(y(7)*y(4)*T235));
  g1(5,7)=(-(T15*y(4)));
  g1(6,7)=1;
  g1(6,12)=(-((params(8)*y(12)-(1+params(8)*y(12)))/(y(12)*y(12))));
  g1(7,2)=1;
  g1(7,12)=(-y(26));
  g1(7,26)=(-y(12));
  g1(8,13)=1;
  g1(8,14)=(-(params(6)*y(15)));
  g1(8,15)=(-(params(6)*y(14)));
  g1(9,3)=(-(y(6)*T15*y(13)*(1+y(16))/y(15)));
  g1(9,5)=(-(y(6)*y(13)*y(3)*(1+y(16))/y(15)*T235));
  g1(9,6)=(-(T15*y(13)*y(3)*(1+y(16))/y(15)));
  g1(9,13)=(-(y(6)*T15*y(3)*(1+y(16))/y(15)));
  g1(9,14)=1;
  g1(9,15)=(-(y(6)*T15*y(13)*y(3)*(-(1+y(16)))/(y(15)*y(15))-(-(y(17)*y(18)*y(20)))/(y(15)*y(20)*y(15)*y(20))));
  g1(9,16)=(-(y(6)*T15*y(13)*y(3)*1/y(15)));
  g1(9,17)=y(18)/(y(15)*y(20));
  g1(9,18)=y(17)/(y(15)*y(20));
  g1(9,20)=(-(y(15)*y(17)*y(18)))/(y(15)*y(20)*y(15)*y(20));
  g1(10,3)=(y(7)-y(6))*T15*y(13);
  g1(10,5)=(y(7)-y(6))*y(3)*y(13)*T235;
  g1(10,6)=(-(T15*y(3)*y(13)));
  g1(10,7)=T15*y(3)*y(13);
  g1(10,13)=y(3)*T15*(y(7)-y(6));
  g1(10,15)=(-(y(16)/(1+y(16))));
  g1(10,16)=(-((y(15)*(1+y(16))-y(15)*y(16))/((1+y(16))*(1+y(16)))));
  g1(11,3)=(y(8)-y(6))*T15*y(13);
  g1(11,5)=(y(8)-y(6))*y(3)*y(13)*T235;
  g1(11,6)=(-(T15*y(3)*y(13)));
  g1(11,8)=T15*y(3)*y(13);
  g1(11,13)=y(3)*T15*(y(8)-y(6));
  g1(11,16)=(-(y(17)/((1+y(16))*(1+y(16)))));
  g1(11,17)=(-((-1)/(1+y(16))));
  g1(12,21)=1;
  g1(12,22)=(-(params(5)/(params(5)-1)/y(23)));
  g1(12,23)=(-((-(params(5)/(params(5)-1)*y(22)))/(y(23)*y(23))));
  g1(13,3)=(-(y(23)*params(1)*T95));
  g1(13,5)=(-(y(23)*y(3)*params(1)*T248));
  g1(13,23)=1-y(3)*params(1)*T95;
  g1(13,25)=(-1);
  g1(14,3)=(-(y(22)*params(1)*T103));
  g1(14,5)=(-(y(22)*y(3)*params(1)*T252));
  g1(14,10)=(-(y(25)*1/y(24)));
  g1(14,22)=1-y(3)*params(1)*T103;
  g1(14,24)=(-(y(25)*(-y(10))/(y(24)*y(24))));
  g1(14,25)=(-(y(10)/y(24)));
  g1(15,11)=(-(y(24)/y(29)));
  g1(15,24)=(-(y(11)/y(29)));
  g1(15,25)=1;
  g1(15,29)=(-((-(y(11)*y(24)))/(y(29)*y(29))));
  g1(16,5)=(-(params(1)*T248));
  g1(16,21)=(-((1-params(1))*getPowerDeriv(y(21),1-params(5),1)));
  g1(17,5)=(-(y(29)*params(1)*T252));
  g1(17,21)=(-((1-params(1))*getPowerDeriv(y(21),(-params(5)),1)));
  g1(17,29)=1-params(1)*T103;
  g1(18,12)=y(27);
  g1(18,18)=(-1);
  g1(18,27)=y(12);
  g1(19,5)=(-((1-params(13))*params(11)*1/y(5)));
  g1(19,9)=1/y(9)-params(13)*1/y(9);
  g1(20,8)=1;
  g1(20,9)=(-1);
  g1(21,6)=1;
  g1(22,5)=(-((1-params(13))*params(10)*params(11)*1/y(5)));
  g1(22,27)=1/y(27)-params(13)*1/y(27);
  g1(23,12)=y(28);
  g1(23,18)=1;
  g1(23,19)=(-1);
  g1(23,20)=(-1);
  g1(23,28)=y(12);
  g1(24,12)=y(28);
  g1(24,14)=(-y(20));
  g1(24,20)=(-y(14));
  g1(24,28)=y(12);
  g1(25,5)=(-((y(28)*y(12)*(y(7)-y(6))+y(18)*(y(8)-y(6))+y(6)*y(20))*params(6)*T235));
  g1(25,6)=(-(T15*params(6)*(y(20)+y(28)*(-y(12))-y(18))));
  g1(25,7)=(-(y(12)*y(28)*T15*params(6)));
  g1(25,8)=(-(y(18)*T15*params(6)));
  g1(25,12)=(-(T15*params(6)*(y(7)-y(6))*y(28)));
  g1(25,18)=(-((y(8)-y(6))*T15*params(6)));
  g1(25,20)=1-y(6)*T15*params(6);
  g1(25,28)=(-(T15*params(6)*y(12)*(y(7)-y(6))));
  g1(26,26)=1;
  g1(26,27)=(-1);
  g1(26,28)=(-1);
  g1(27,1)=(-1);
  g1(27,2)=(-1);
  g1(27,25)=1;
  g1(28,24)=1/y(24)-params(14)*1/y(24);
  g1(29,15)=1/y(15)-params(15)*1/y(15);
  g1(30,1)=(-1);
  g1(30,2)=(-1);
  g1(30,30)=1;
  g1(31,6)=(-((-y(7))/(y(6)*y(6))));
  g1(31,7)=(-(1/y(6)));
  g1(31,31)=1;
  if ~isreal(g1)
    g1 = real(g1)+2*imag(g1);
  end
if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],31,961);
if nargout >= 4,
  %
  % Third order derivatives
  %

  g3 = sparse([],[],[],31,29791);
end
end
end
end
